pub async fn new_hdfs_object_store(
hdfs_config: &HdfsConfig,
) -> Result<ObjectStore>Expand description
Creates an object store backed by a native HDFS client.
pub async fn new_hdfs_object_store(
hdfs_config: &HdfsConfig,
) -> Result<ObjectStore>Creates an object store backed by a native HDFS client.